@@ -55,13 +55,13 @@
 #define PLACEMENT_MOUSE                 0
 #define PLACEMENT_ROOT                  1
 
-#define CFG_NONE                        0
+#define NO_CFG_FLAG                     0
 #define CFG_CONSTRAINED                 (1<<0)
 #define CFG_REQUEST                     (1<<1)
 #define CFG_NOTIFY                      (1<<2)
 #define CFG_FORCE_REDRAW                (1<<3)
 
-#define FOCUS_NONE                      0
+#define NO_FOCUS_FLAG                   0
 #define FOCUS_SORT                      (1<<0)
 #define FOCUS_IGNORE_MODAL              (1<<1)
 #define FOCUS_FORCE                     (1<<2)
@@ -72,7 +72,7 @@
 #define INCLUDE_SKIP_PAGER              (1<<3)
 #define INCLUDE_SKIP_TASKBAR            (1<<4)
 
-#define UPDATE_NONE                     0
+#define NO_UPDATE_FLAG                  0
 #define UPDATE_KEYGRABS                 (1<<0)
 #define UPDATE_FRAME                    (1<<1)
 #define UPDATE_GRAVITY                  (1<<2)
@@ -232,21 +232,22 @@ struct _Client
 extern Client *clients;
 extern unsigned int client_count;
 
-inline Client *clientGetTransient (Client *);
-inline gboolean clientIsTransient (Client *);
-inline gboolean clientIsModal (Client *);
-inline gboolean clientIsTransientOrModal (Client *);
-inline gboolean clientSameGroup (Client *, Client *);
-inline gboolean clientIsTransientFor (Client *, Client *);
-inline gboolean clientIsModalFor (Client *, Client *);
-inline gboolean clientIsTransientOrModalFor (Client *, Client *);
-inline gboolean clientIsTransientForGroup (Client *);
-inline gboolean clientIsModalForGroup (Client *);
-inline gboolean clientIsTransientOrModalForGroup (Client *);
+Client *clientGetTransient (Client *);
+gboolean clientIsTransient (Client *);
+gboolean clientIsModal (Client *);
+gboolean clientIsTransientOrModal (Client *);
+gboolean clientSameGroup (Client *, Client *);
+gboolean clientIsTransientFor (Client *, Client *);
+gboolean clientIsModalFor (Client *, Client *);
+gboolean clientIsTransientOrModalFor (Client *, Client *);
+gboolean clientIsTransientForGroup (Client *);
+gboolean clientIsModalForGroup (Client *);
+gboolean clientIsTransientOrModalForGroup (Client *);
 void clientSetNetState (Client *);
 void clientUpdateWinState (Client *, XClientMessageEvent *);
 void clientUpdateNetState (Client *, XClientMessageEvent *);
-void clientGetNetWmType (Client * c);
+void clientGetNetWmType (Client *);
+void clientPassGrabButton1(Client *);
 void clientCoordGravitate (Client *, int, int *, int *);
 void clientGravitate (Client *, int);
 void clientConfigure (Client *, XWindowChanges *, int, unsigned short);
@@ -288,9 +289,9 @@ void clientToggleShaded (Client *);
 void clientStick (Client *, gboolean);
 void clientUnstick (Client *, gboolean);
 void clientToggleSticky (Client *, gboolean);
-inline void clientRemoveMaximizeFlag (Client *);
+void clientRemoveMaximizeFlag (Client *);
 void clientToggleMaximized (Client *, int);
-inline gboolean clientAcceptFocus (Client * c);
+gboolean clientAcceptFocus (Client * c);
 void clientUpdateFocus (Client *, unsigned short);
 void clientSetFocus (Client *, unsigned short);
 Client *clientGetFocus ();
