@@ -32,7 +32,7 @@
 #include <X11/Xatom.h>
 #include <glib.h>
 
-#define MWM_HINTS_ELEMENTS                      5L
+#define MWM_HINTS_ELEMENTS                      3L
 
 #define MWM_HINTS_FUNCTIONS                     (1L << 0)
 #define MWM_HINTS_DECORATIONS                   (1L << 1)
@@ -97,11 +97,9 @@
 
 typedef struct
 {
-    CARD32 flags;
-    CARD32 functions;
-    CARD32 decorations;
-    INT32  inputMode;
-    CARD32 status;
+    unsigned long flags;
+    unsigned long functions;
+    unsigned long decorations;
 }
 PropMwmHints;
 
@@ -178,6 +176,12 @@ extern Atom net_wm_window_type_toolbar;
 extern Atom net_wm_window_type_utility;
 extern Atom net_workarea;
 
+/* Systray similation for older KDE apps */
+extern Atom kde_net_wm_system_tray_window_for;
+extern Atom net_system_tray_manager;
+extern Atom net_system_tray_selection;
+extern Atom net_system_tray_opcode;
+
 void initICCCMHints (Display *);
 unsigned long getWMState (Display *, Window);
 void setWMState (Display *, Window, unsigned long);
@@ -185,21 +189,25 @@ void initMotifHints (Display *);
 PropMwmHints *getMotifHints (Display *, Window);
 unsigned int getWMProtocols (Display *, Window);
 void initGnomeHints (Display *);
+void initSystrayHints (Display *, int);
 gboolean getHint (Display *, Window, Atom, long *);
 void setHint (Display *, Window, Atom, long);
-void getGnomeDesktopMargins (Display *, int, CARD32 *);
+void getGnomeDesktopMargins (Display *, int, int *);
 void setGnomeProtocols (Display *, int, Window);
 void initNetHints (Display * dpy);
 void set_net_supported_hint (Display *, int, Window);
 gboolean get_atom_list (Display *, Window, Atom, Atom **, int *);
 gboolean get_cardinal_list (Display *, Window, Atom, unsigned long **, int *);
-void set_net_workarea (Display *, int, int, CARD32 *);
+void set_net_workarea (Display *, int, int, int *);
 void init_net_desktop_params (Display *, int, int);
 void set_utf8_string_hint (Display *, Window, Atom, const char *);
 void getTransientFor (Display *, int, Window, Window *);
 void getWindowName (Display *, Window, char **);
 gboolean get_utf8_string (Display *, Window, Atom, char **);
 void getWindowName (Display *, Window, char **);
+gboolean checkKdeSystrayWindow(Display *, Window);
+void sendSystrayReqDock(Display *, Window, Window);
+Window getSystrayWindow (Display *);
 gboolean getWindowRole (Display *, Window, char **);
 Window getClientLeader (Display *, Window);
 gboolean getClientID (Display *, Window, char **);
